@@ -39,11 +39,11 @@ sub new {
         port               => $args{port} || 8080,
         timeout            => $args{timeout} || 300,
         keepalive_timeout  => $args{keepalive_timeout} || 2,
-        max_keepalive_reqs => $args{max_keepalive_reqs},
+        max_keepalive_reqs => $args{max_keepalive_reqs} || 1,
         server_software    => $args{server_software} || $class,
         server_ready       => $args{server_ready} || sub {},
-        max_reqs_per_child => $args{max_reqs_per_child} || 100,
-        max_keepalive_reqs => 1,
+        max_reqs_per_child =>
+            $args{max_reqs_per_child} || $args{max_requests} || 100,
         is_multiprocess    => Plack::Util::FALSE,
     }, $class;
 
